.. Copyright (C) 2020 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2020 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

See Also
========

- Manual pages: :man:`hier(7)`

- `Filesystem Hierarchy Standard v3.0 specification`__

  .. __: https://refspecs.linuxfoundation.org/FHS_3.0/fhs/index.html
